# -------------------------------------------------------------
# NDN Hydra Tlv Types
# -------------------------------------------------------------
#  @Project: NDN Hydra
#  @Date:    2021-01-25
#  @Authors: Please check AUTHORS.rst
#  @Source-Code:   https://github.com/justincpresley/ndn-hydra
#  @Documentation: https://ndn-hydra.readthedocs.io
#  @Pip-Library:   https://pypi.org/project/ndn-hydra
# -------------------------------------------------------------

class HydraTlvTypes:
    MESSAGE = 200
    MESSAGE_TYPE = 201
    FILE = 202
    PACKETS = 203
    PACKET_SIZE = 204
    SIZE = 205
    STATUS_CODE = 206
    CMD_URI= 207